@@ -8,10 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
+import aws_cdk._jsii
+import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-iam-floyd", "0.100.0", __name__[0:-6], "cdk-iam-floyd@0.100.0.jsii.tgz"
+    "cdk-iam-floyd", "0.374.0", __name__[0:-6], "cdk-iam-floyd@0.374.0.jsii.tgz"
 )
 
 __all__ = [
